``ExposoGraph.grounding``
=========================

Grounding and graph-preparation helpers used to reconcile free-text or seeded
content with canonical reference entities.

.. automodule:: ExposoGraph.grounding
   :members:
   :undoc-members:
